#!/bin/sh

#
# Arguments check and suage information
#
SRC="."
DEST="$1"
if [ -z "$DEST" ]; then
cat<<EOF

Unix-Tools Galaxy Installation script.
	
This script copies the Unix-Tools files into the specified Galaxy directory.
	
Usage: $0 [GALAXY-DIRECTORY]
	
	GALAXY-DIRECTORY - root directory of the Galaxy server.
	
EOF
	exit
fi


echo 
echo "Unix Tools Galaxy Installation script."
echo

#
# Sanity checks for the specified galaxy directory
#
echo -n "Checking Galaxy destination directory..."
[ -d "$DEST" ] ||
    { echo "Error: directory '$DEST' does not exist!" ; exit 1 ; }
    
[ -r "$DEST/tool_conf.xml" ] ||
    { echo "Error: file '$DEST/tool_conf.xml' does not exist! (is '$DEST' the root of the Galaxy server?)" ; exit 1 ; }
    
for subdir in tools tool-data test-data static; do
	[ -d "$DEST/$subdir" ] ||
		{ echo "Error: sub-directory '$DEST/$subdir' does not exist! (is '$DEST' the root of the Galaxy server?)" ; exit 1 ; }
done
echo "ok"

#
# Sanity checks for the Unix Tools files
#
echo -n "Checking Unix Tools source directory..."
[ -r "$SRC/tool_conf.xml.add" ] ||
    { echo "Error: file '$SRC/tool_conf.xml.add' does not exist! (is '$SRC' the root of Unix-Tools package?)" ; exit 1 ; }
    
for subdir in tools test-data ; do
	[ -d "$SRC/$subdir" ] ||
		{ echo "Error: sub-directory '$SRC/$subdir' does not exist! (is '$SRC' the root of Unix-Tools package?)" ; exit 1 ; }
done
echo "ok"


#
# Copy Unix-Tools files into Galaxy server
#
echo -n "Copying test-data files..."
cp $SRC/test-data/* "$DEST/test-data" || exit 1 ;
echo "OK"

echo -n "Creaing tools/unix_tools directory..."
mkdir -p "$DEST/tools/unix_tools" || exit 1;
echo "OK"

#
# Be extra careful when copying the XML files - 
# Ask the user for confirmation if the XML files already exists
# (so that if they were changed, they will not be blindly overwriten)
echo "==="
echo "=== NOTE:"
echo "==="
echo "If the Unix-Tools XML files already exist on your galaxy server,"
echo "You will be prompted to confirm overwriting them."
echo "If you have made any changes to the XML files, DO NOT overwrite your files."
echo 
echo -n "Copying Unix-Tools XML tool configuration..."
cp -i $SRC/tools/unix_tools/* "$DEST/tools/unix_tools"
echo "ok"


#
# Instruct the user what to do next
#
cat<<EOF
Unix-Tools files copied to your galaxy server directory.

Additionally, you'll need to make the following manual configurations:

Merge the content of:
	$SRC/tool_conf.xml.add
into
	$DEST/tool_conf.xml
	
EOF

